@@ -5,7 +5,6 @@
 
 #include "enums.h"
 #include "htmlutils.h"
-#include "messagepart.h"
 #include "mimetreeparser_core_debug.h"
 #include "objecttreeparser.h"
 #include "utils.h"
@@ -238,7 +237,7 @@ public:
         }
     }
 
-    PartModel *q;
+    PartModel *const q;
     MimeTreeParser::MessagePart::List mParts;
     QHash<MimeTreeParser::MessagePart *, QByteArray> mMimeTypeCache;
     QHash<MimeTreeParser::MessagePart *, MimeTreeParser::MessagePart::List> mEncapsulatedParts;
